@@ -94,10 +94,11 @@ def fetch_view_files(proj):
         if 'join' in explore:
             for join in explore['join']:
                 true_view_names[explore['name']].append(join['name'])
-                if 'view_name' in join:
-                    true_view_names[explore['name']].append(join['view_name'])
-                if 'from' in join:
-                    true_view_names[explore['name']].append(join['from'])
+                if 'view_name' in join.__dict__.keys():
+                    true_view_names[explore['name']].append(
+                        join['view_name'].value)
+                if 'from' in join.__dict__.keys():
+                    true_view_names[explore['name']].append(join['from'].value)
     return true_view_names
 
 
@@ -112,24 +113,34 @@ def get_sql_table_name(proj):
         For example:
         ['public.order_items','public.inventory_items','public.events']
     """
-    response = []
+    view_list = defaultdict(list)
+
     for file in proj.files():
         path = file.path
         myFile = proj.file(path)
         if myFile.type == 'partial_model':
             for view in myFile.views:
                 if view.sql_table_name.value:
-                    response.append(view.sql_table_name.value)
+                    view_list[path].append(view.sql_table_name.value)
 
-    return response
+    return view_list
+
+
+def get_sql_table_name_list(sql_table_name_dict, key: True):
+    response = []
+    for k, v in sql_table_name_dict.items():
+        if key:
+            response.append(k)
+        else:
+            response.append(v)
+
+    return response if key else list(chain(*response))
 
 
 def parse_sql(sdk, qid: int):
     """Idenfies the base tables and joins used by a Looker query.
 
     Iterates over a list of PyLookML files identifies view files aand returns a list of the sql_table_names if they exist in an object of type 'View'
-    Args:
-        sdk: Looker SDK object
         qid: (int) query_id from a  Looker query (n.b. NOT THE SAME AS A QID in the url)
     Returns:
         A list of all the tables that are found from a Looker generated SQL query.
@@ -273,9 +284,7 @@ def all_joins(myresults):
             for name in sql_table_name:
                 if sql == name:
                     result.append(sql)
-        logger.wtf(f'result= {result}')
         myresults[element]['used_joins'] = result
-        logger.wtf(myresults)
     return myresults
 
 
@@ -331,6 +340,9 @@ def find_unused_views(myresults):
 def match_view_to_dash(content_results, explore_results, sql_table_name, proj):
     tables_in_explore = []
 
+    sql_table_name_ = get_sql_table_name_list(sql_table_name, key=False)
+    sql_table_paths_ = get_sql_table_name_list(sql_table_name, key=True)
+
     for content in content_results:
         result = defaultdict(list)
         result['dashboard_id'] = content['dashboard.id']
@@ -338,7 +350,8 @@ def match_view_to_dash(content_results, explore_results, sql_table_name, proj):
         result['sql_joins'] = content['sql_joins']
         result['fields_used'] = content['query.formatted_fields']
 
-        result['sql_table_name'] = sql_table_name
+        result['sql_table_name'] = sql_table_name_
+        result['lookml_file_name'] = sql_table_paths_
 
         for explore, tables in explore_results.items():
             if content['query.view'] == explore:
@@ -371,10 +384,12 @@ def main(**kwargs):
     content_results = get_dashboards(sdk)
     db_response = get_sql_from_elements(sdk, content_results)
     explore_results = fetch_view_files(proj=project)
+
     sql_table_names = get_sql_table_name(proj=project)
 
     combine = match_view_to_dash(
         db_response, explore_results, sql_table_names, proj=project)
+
     for element in range(0, len(combine)):
         match_join_per_query(combine[element])
         match_views_per_query(combine[element], project)
@@ -411,4 +426,7 @@ def main(**kwargs):
 
 
 if __name__ == "__main__":
-    main(ini_file="/usr/local/google/home/hugoselbie/code_sample/py/projects/ini/k8.ini")
+    main(
+        ini_file="/usr/local/google/home/hugoselbie/code_sample/py/projects/ini/k8.ini",
+        path='./output.csv',
+        project='./tests/test_lookml_files/the_look')
